module top;

wire i_rfe_rfeout_sig;
wire i_env_vagc_sig;
wire i_env_vsup_sig;
wire i_env_gnda_sig;
wire i_env_rfein_sig;
wire i_env_lo_sig;

rfe i_rfe (
      .vagc(      i_env_vagc_sig   ),
      .vsup(      i_env_vsup_sig   ),
      .gnda(      i_env_gnda_sig   ),
      .rfein(     i_env_rfein_sig  ),
      .rfeout(    i_rfe_rfeout_sig ),
      .lo(        i_env_lo_sig     ) 
      );

env i_env (
      .vagc(      i_env_vagc_sig   ),
      .vsup(      i_env_vsup_sig   ),
      .gnda(      i_env_gnda_sig   ),
      .rfein(     i_env_rfein_sig  ),
      .lo(        i_env_lo_sig     ),
      .rfeout(    i_rfe_rfeout_sig ) 
      );

endmodule
